@@ -74,7 +74,7 @@ OnepModel14<- function
                                       t_start,
                                       t_stop
                                       )
-    if(class(In)=="data.frame"){
+    if(inherits(In, "data.frame")){
       x=In[,1]  
       y=In[,2]  
       inputFlux=function(t0){as.numeric(spline(x,y,xout=t0)[2])}
@@ -85,7 +85,7 @@ OnepModel14<- function
                       )   
     }
     if(length(xi)==1) fX=function(t){xi}
-    if(class(xi)=="data.frame"){
+    if(inherits(xi, "data.frame")){
       X=xi[,1]
       Y=xi[,2]
       fX=function(t){as.numeric(spline(X,Y,xout=t)[2])}
