@@ -157,7 +157,7 @@ ThreepFeedbackModel<- function
             t_end
         )
       }
-      if(class(In)=="data.frame"){
+      if(inherits(In, "data.frame")){
          x=In[,1]  
          y=In[,2]
          inputFlux=splinefun(x,y)
@@ -176,7 +176,7 @@ ThreepFeedbackModel<- function
         fX=function(t){xi}
         Af=BoundLinDecompOp(function(t){fX(t)*A},t_start,t_end)
       }
-      if(class(xi)=="data.frame"){
+      if(inherits(xi, "data.frame")){
         X=xi[,1]
       	Y=xi[,2]
         fX=splinefun(X,Y)
